/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.model;

import org.openide.util.NbBundle;

/**
 * Issuing Agency enum Can validate a issuing agency number
 *
 * @author johan
 */
@NbBundle.Messages({"IssuingAgency AGRONL=Kvk number should contain 8 digits"})
public enum IssuingAgency {

    AGRONL("\\d{8}"),
    OTHER(null);
    private static final String BUNDLE_PREFIX = "IssuingAgency ";

    private IssuingAgency(String EnterpriseIdPattern) {
        this.enterpriseIdPattern = EnterpriseIdPattern;
    }
    private final String enterpriseIdPattern;

    public String getEnterpriseIdPattern() {
        return enterpriseIdPattern;
    }

    /**
     * <p>Get message which describes the pattern</p> For instance, 'some
     * pattern should be n digits '
     *
     * @return
     */
    public String getPatternMessage() {
        return this.equals(IssuingAgency.OTHER) ? "" : NbBundle.getMessage(getClass(), BUNDLE_PREFIX + toString());
    }

    /**
     * validate enterpriseId format. EDI-teelt++ spec: depends on issuing agency
     * (e.g. KvK-number for AGRONL: n8)
     *
     * @param enterpriseId
     * @return
     */
    public boolean isValidEnterpriseId(String enterpriseId) {
        // should not be empty:
        if (enterpriseId == null || enterpriseId.isEmpty()) {
            return false;
        }

        // should match pattern (if any):
        if (enterpriseIdPattern != null && !enterpriseId.matches(enterpriseIdPattern)) {
            return false;
        }

        return true;
    }
}
