/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.model;

/**
 *
 * @author johan
 */
public enum ItemIdType {
    // EDI-Teelt++ ItemIdTypes:

    FRM, FLD, CFD, AFD, OPR, TZN, ALL, PRT,
    // ISOXML:
    TSK,
    // Agrosense entities not (yet) in any specification:
    CPU, VCE, IMT,
    //TODO: fieldplan; 
    CRP, CLN, VTY, CTN,
    //Tasks
    FTK, STK,
    //Sensor Run
    SRU;

    /**
     * This method can be used to fetch the ItemIdType for a specific class. It
     * uses the simple name of the class passed as parameter in a switch
     * statement to return the correct ItemIdType.
     *
     * @param clazz Class that you wish to receive the ItemIdType for
     * @return ItemTypeId for the class passed as parameter OR null if no
     * ItemIdType could be found for the class. Not all classes are entities
     * with defined ItemIdTypes!
     */
    public static ItemIdType fromClass(Class clazz) {
        String className = clazz.getSimpleName();
        switch (className) {
            case "Field":
                return FLD;
            case "Farm":
                return FRM;
            case "CropField":
                return CFD;
            case "ActivityField":
                return AFD;
            case "TreatmentZone":
                return TZN;
            case "Vehicle":
                return VCE;
            case "Implement":
                return IMT;
            case "CropDefinition":
                return CTN;
            case "Crop":
                return CRP;
            case "Classification":
                return CLN;
            case "SensorRun":
                return SRU;                
            case "Variety":
                return VTY;
            case "FieldTask":
                return FTK;
            case "SprayTask":
                return STK;
            default:
                return null;
        }
    }
}
